==> drjournal-0.1.0-py3-none-any.whl: drjournal/journal.py <==
#!/usr/bin/env python3
import argparse
import datetime
import os
import shutil
import subprocess
import sys
import tempfile
import textwrap

import pydndc

def main() -> int:
    parser = argparse.ArgumentParser()
    parser.add_argument('--gui', action='store_true')
    args = parser.parse_args()
    return run(**vars(args))

def run(gui:bool) -> int:
    GIT = shutil.which('git')
    if not GIT:
        print("git not found, aborting", file=sys.stderr)
        return 1
    if sys.platform == 'darwin':
        OPEN = shutil.which('open')
        GUI = '/Applications/MacVim.app/Contents/bin/mvim', '-f', '-c', 'au VimLeave * maca hide:'
        JOURNALFOLDER = os.path.expanduser('~/Documents/Journals')
    elif sys.platform == 'linux':
        OPEN = shutil.which('xdg-open')
        GUI = shutil.which('gvim'),  '-f'
        JOURNALFOLDER = os.path.expanduser('~/Journals')
    else:
        OPEN = 'start'
        GUI = shutil.which('gvim'),  '-f'
        # probably some way of properly getting this
        JOURNALFOLDER = os.path.expanduser('~/Documents and Settings/Journals')
    if gui and not GUI[0]:
        print('gvim not found, aborting', file=sys.stderr)
        return 1
    if not os.path.isdir(JOURNALFOLDER):
        os.makedirs(JOURNALFOLDER, exist_ok=True)
        subprocess.check_call([GIT, 'init'], cwd=JOURNALFOLDER)


    NOW = datetime.datetime.now()
    LASTMONTH = NOW.replace(day=1) - datetime.timedelta(days=1)
    NEXTMONTH = NOW.replace(day=28) + datetime.timedelta(days=7)

    YEARMONTH = NOW.strftime('%Y-%m')
    JOURNALFILE = os.path.join(JOURNALFOLDER, YEARMONTH) + '.dnd'
    JOURNALHTML = os.path.join(JOURNALFOLDER, YEARMONTH) + '.html'
    PREVIOUSFILE = LASTMONTH.strftime('%Y-%m') + '.html'
    NEXTFILE = NEXTMONTH.strftime('%Y-%m') + '.html'


    F = pydndc.Flags
    ctx = pydndc.Context(flags=F.DONT_INLINE_IMAGES)
    ctx.logger = pydndc.stderr_logger
    if os.path.isfile(JOURNALFILE):
        ctx.root.parse_file(JOURNALFILE)
    else:
        ctx.root.parse(textwrap.dedent('''
        ::nav #id(toc)
        ::css
            * {
                box-sizing: border-box;
            }
            body {
                display: grid;
                grid-template-columns: max-content auto;
                grid-template-rows: max-content auto;
                grid-column-gap: 4em;
                height: 100vh;
                margin: 0;
            }
            #top {
                grid-column: 1/3;
                grid-row: 1;
                padding: 8px;
            }
            #content {
                grid-column: 2;
                grid-row: 2;
                overflow-y: auto;
                padding: 8px;
            }
            #toc {
                grid-column: 1;
                grid-row: 2;
                overflow-y: auto;
                padding: 8px;
            }
            .day {
                width: 40em;
                padding-left: 4em;
            }
            #top {
                display: flex;
                justify-content: space-between;
            }
            /*endcss*/
        ::div #id(top)
          [Last Month]
          ''' f'''
          {NOW.strftime("%B %Y")}::title
          [Next Month]
        ::div #id(content)
        ::links
            Last Month = {PREVIOUSFILE}
            Next Month = {NEXTFILE}
        '''
        ))
    content = ctx.node_by_id('content')
    assert content is not None
    today = NOW.strftime('%A %B %d')
    today_node = ctx.node_by_id(today)
    if today_node is None:
        today_node = content.make_child(pydndc.NodeType.MD, today)
        today_node.add_class('day')
    else:
        today_node.make_child(pydndc.NodeType.PARA).append_child('<hr>')
    today_node.make_child(pydndc.NodeType.PARA).append_child(NOW.strftime('<i>written at %I:%M%p</i>').lower())

    fd, tmp = tempfile.mkstemp(suffix='.dnd', text=True)
    os.close(fd)
    command = [*GUI, tmp] if gui else ['vim', tmp]
    subprocess.check_call(command)
    try:
        with open(tmp) as fp:
            text = fp.read()
    except FileNotFoundError:
        print('Not found, aborting.', file=sys.stderr)
        return 1
    if not text.strip():
        print('Aborting due to empty input file.', file=sys.stderr)
        return 1
    os.unlink(tmp)
    today_node.parse(text)
    output = ctx.format_tree().rstrip()
    with open(JOURNALFILE, 'w') as fp:
        print(output, file=fp)
    ctx.resolve_imports()
    ctx.execute_js()
    ctx.resolve_links()
    ctx.build_toc()
    html = ctx.render()

    with open(JOURNALHTML, 'w') as fp:
        print(html.rstrip(), file=fp)
    subprocess.check_call([OPEN, JOURNALHTML])
    subprocess.check_call([GIT, 'add', JOURNALFILE], cwd=JOURNALFOLDER)
    subprocess.check_call([GIT, 'commit', '--allow-empty-message', '-q', '-m', ''], cwd=JOURNALFOLDER)
    return 0

if __name__ == '__main__':
    ret = main()
    sys.exit(ret)

==> drjournal-0.1.1-py3-none-any.whl: drjournal/journal.py <==
#!/usr/bin/env python3
import argparse
import datetime
import os
import shutil
import subprocess
import sys
import tempfile
import textwrap
import pathlib

import pydndc

def main() -> int:
    parser = argparse.ArgumentParser()
    parser.add_argument('--gui', action='store_true')
    args = parser.parse_args()
    return run(**vars(args))

def run(gui:bool) -> int:
    GIT = shutil.which('git')
    if not GIT:
        print("git not found, aborting", file=sys.stderr)
        return 1
    if sys.platform == 'darwin':
        OPEN = shutil.which('open')
        GUI = '/Applications/MacVim.app/Contents/bin/mvim', '-f', '-c', 'au VimLeave * maca hide:'
        JOURNALFOLDER = os.path.expanduser('~/Documents/Journals')
    elif sys.platform == 'linux':
        OPEN = shutil.which('xdg-open')
        GUI = shutil.which('gvim'),  '-f'
        JOURNALFOLDER = os.path.expanduser('~/Journals')
    else:
        assert sys.platform == 'win32'
        OPEN = 'start'
        GUI = shutil.which('gvim'),  '-f'
        import ctypes.wintypes
        CSIDL_PERSONAL = 5       # My Documents
        SHGFP_TYPE_CURRENT = 0   # Get current, not default value

        buf= ctypes.create_unicode_buffer(ctypes.wintypes.MAX_PATH)
        ctypes.windll.shell32.SHGetFolderPathW(None, CSIDL_PERSONAL, None, SHGFP_TYPE_CURRENT, buf)
        JOURNALFOLDER = os.path.join(buf.value, 'Journals')
    if gui and not GUI[0]:
        print('gvim not found, aborting', file=sys.stderr)
        return 1
    if not os.path.isdir(JOURNALFOLDER):
        os.makedirs(JOURNALFOLDER, exist_ok=True)
        subprocess.check_call([GIT, 'init'], cwd=JOURNALFOLDER)


    NOW = datetime.datetime.now()
    LASTMONTH = NOW.replace(day=1) - datetime.timedelta(days=1)
    NEXTMONTH = NOW.replace(day=28) + datetime.timedelta(days=7)

    YEARMONTH = NOW.strftime('%Y-%m')
    JOURNALFILE = os.path.join(JOURNALFOLDER, YEARMONTH) + '.dnd'
    JOURNALHTML = os.path.join(JOURNALFOLDER, YEARMONTH) + '.html'
    PREVIOUSFILE = LASTMONTH.strftime('%Y-%m') + '.html'
    NEXTFILE = NEXTMONTH.strftime('%Y-%m') + '.html'


    F = pydndc.Flags
    ctx = pydndc.Context(flags=F.DONT_INLINE_IMAGES)
    ctx.logger = pydndc.stderr_logger
    if os.path.isfile(JOURNALFILE):
        ctx.root.parse_file(JOURNALFILE)
    else:
        ctx.root.parse(textwrap.dedent('''
        ::nav #id(toc)
        ::css
            * {
                box-sizing: border-box;
            }
            body {
                display: grid;
                grid-template-columns: max-content auto;
                grid-template-rows: max-content auto;
                grid-column-gap: 4em;
                height: 100vh;
                margin: 0;
            }
            #top {
                grid-column: 1/3;
                grid-row: 1;
                padding: 8px;
            }
            #content {
                grid-column: 2;
                grid-row: 2;
                overflow-y: auto;
                padding: 8px;
            }
            #toc {
                grid-column: 1;
                grid-row: 2;
                overflow-y: auto;
                padding: 8px;
            }
            .day {
                width: 40em;
                padding-left: 4em;
            }
            #top {
                display: flex;
                justify-content: space-between;
            }
            /*endcss*/
        ::div #id(top)
          [Last Month]
          ''' f'''
          {NOW.strftime("%B %Y")}::title
          [Next Month]
        ::div #id(content)
        ::links
            Last Month = {PREVIOUSFILE}
            Next Month = {NEXTFILE}
        '''
        ))
    content = ctx.node_by_id('content')
    assert content is not None
    today = NOW.strftime('%A %B %d')
    today_node = ctx.node_by_id(today)
    if today_node is None:
        today_node = content.make_child(pydndc.NodeType.MD, today)
        today_node.add_class('day')
    else:
        today_node.make_child(pydndc.NodeType.PARA).append_child('<hr>')
    today_node.make_child(pydndc.NodeType.PARA).append_child(NOW.strftime('<i>written at %I:%M%p</i>').lower())

    fd, tmp = tempfile.mkstemp(suffix='.dnd', text=True)
    os.close(fd)
    command = [*GUI, tmp] if gui else ['vim', tmp]
    subprocess.check_call(command)
    try:
        with open(tmp) as fp:
            text = fp.read()
    except FileNotFoundError:
        print('Not found, aborting.', file=sys.stderr)
        return 1
    if not text.strip():
        print('Aborting due to empty input file.', file=sys.stderr)
        return 1
    os.unlink(tmp)
    today_node.parse(text)
    output = ctx.format_tree().rstrip()
    with open(JOURNALFILE, 'w') as fp:
        print(output, file=fp)
    ctx.resolve_imports()
    ctx.execute_js()
    ctx.resolve_links()
    ctx.build_toc()
    html = ctx.render()

    with open(JOURNALHTML, 'w') as fp:
        print(html.rstrip(), file=fp)

    if OPEN:
        if sys.platform == 'win32':
            cmd = OPEN+' '+pathlib.Path(JOURNALHTML).as_uri()
            os.system(cmd)
        else:
            subprocess.check_call([OPEN, JOURNALHTML])

    subprocess.check_call([GIT, 'add', JOURNALFILE], cwd=JOURNALFOLDER)
    subprocess.check_call([GIT, 'commit', '--allow-empty-message', '-q', '-m', ''], cwd=JOURNALFOLDER)
    return 0

if __name__ == '__main__':
    ret = main()
    sys.exit(ret)
